@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.42.2.6 2003/05/01 12:02:21 joern Exp $
+# $Id: Config.pm,v 1.42.2.7 2003/05/23 19:49:35 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -231,13 +231,6 @@ my %CONFIG_PARAMETER = (
 		type  => 'string',
 		value => '',
 	},
-	dvdcss_method => {
-		label => "libdvdcss method",
-		type  => 'string',
-		value => 'title',
-		presets => ['title', 'key', 'disc'],
-		onload => sub { $ENV{DVDCSS_METHOD} = $_[0] }
-	},
 );
 
 my @CONFIG_ORDER = (
@@ -267,7 +260,6 @@ my @CONFIG_ORDER = (
 	"Miscellaneous options" => [qw(
 		default_video_codec  show_tooltips
 		main_window_width    main_window_height
-		dvdcss_method        
 	)],
 );
 
@@ -533,7 +525,7 @@ sub save {
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or die "can't write $filename";
-	print $fh q{# $Id: Config.pm,v 1.42.2.6 2003/05/01 12:02:21 joern Exp $},"\n";
+	print $fh q{# $Id: Config.pm,v 1.42.2.7 2003/05/23 19:49:35 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
@@ -643,7 +635,6 @@ sub test_burn_mkisofs_cmd   	{ _executable (@_) 	}
 sub test_burn_vcdimager_cmd   	{ _executable (@_) 	}
 sub test_burn_cdrdao_buffers    { _numeric_or_empty(@_) }
 sub test_cluster_master_port	{ _numeric (@_)		}
-sub test_dvdcss_method		{ _one_of_these (@_, ['disc','title','key'] ) }
 sub test_eject_command		{ _executable (@_) 	}
 
 sub _executable {
