@@ -1,4 +1,4 @@
-# $Id: Project.pm,v 1.41 2003/01/28 20:19:57 joern Exp $
+# $Id: Project.pm,v 1.41.2.1 2003/03/31 08:54:34 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -128,7 +128,7 @@ sub save {
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or confess "can't write $filename";
-	print $fh q{# $Id: Project.pm,v 1.41 2003/01/28 20:19:57 joern Exp $},"\n";
+	print $fh q{# $Id: Project.pm,v 1.41.2.1 2003/03/31 08:54:34 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
@@ -317,22 +317,6 @@ sub copy_ifo_files {
 	1;
 }
 
-sub check_dvd_in_drive {
-	my $self = shift;
-	
-	my $dvd_device = $self->rip_data_source;
-
-	my $command = "tcprobe -i $dvd_device >/dev/null 2>&1";
-
-	system ($command);
-	
-	if ( $? ) {
-		croak "No DVD found at $dvd_device.";
-	}
-	
-	1;
-}
-
 sub dvd_is_mounted {
 	my $self = shift;
 	
